package com.cmcc.system.internal;

import java.io.BufferedReader;
import java.io.Closeable;
import java.io.FileReader;
import java.io.IOException;
import java.util.HashMap;
import java.util.Map;
import java.util.Properties;

public class IniReader {
    private Map<String, Properties> sections;
    private Properties properties;

    public IniReader(String filename){
        sections = new HashMap<String, Properties>();
        BufferedReader reader = null;
        try {
            reader = new BufferedReader(new FileReader(filename));
            read(reader);

        } catch (Exception e) {
        } finally {
            silentlyClose(reader);
        }
    }

    private void read(BufferedReader reader) throws IOException {
        String line;
        while ((line = reader.readLine()) != null) {
            parseLine(line);
        }
    }

    private void parseLine(String line) {
        line = line.trim();
        if (line.matches("\\[.*\\]")) {
            String secion = line.replaceFirst("\\[(.*)\\]", "$1");
            properties = new Properties();
            sections.put(secion, properties);
        } else if (line.matches(".*=.*")) {
            if (properties != null) {
                int i = line.indexOf('=');
                String name = line.substring(0, i);
                String value = line.substring(i + 1);
                properties.setProperty(name, value);
            }
        }
    }

    public String getValue(String section, String name) {
        Properties p = sections.get(section);
        if (p == null) {
            return null;
        }
        String value = p.getProperty(name);
        return value;
    }

    private static void silentlyClose(Closeable... closeables) {
        Closeable[] arr = closeables;
        int len = closeables.length;

        for(int i = 0; i < len; ++i) {
            Closeable cl = arr[i];
            try {
                if(cl != null) {
                    cl.close();
                }
            } catch (Exception e) {
            }
        }
    }
}
